import json

import requests
from flask import request, jsonify
from flask_restx import Resource, Namespace, reqparse

from app.defines import StatesCode
from app.utils.jwt_util import login_required
from config import Config

ns = Namespace('index', description='指标配置')

config = Config()

index_list = reqparse.RequestParser(bundle_errors=True)
index_list.add_argument(name='page_size', type=int, location='args', required=False, help='每页记录数量，默认:20')
index_list.add_argument(name='page', type=int, location='args', required=False, help='第几页')
index_list.add_argument(name='parent_id', type=int, location='args', required=False, help='父id')


@ns.route('/index_list')
class IndexApi(Resource):
    # method_decorators = [login_required]

    @ns.doc(description='获取指标配置列表')
    @ns.expect(index_list)
    def get(self):
        parent_id = request.args.get('parent_id')
        page_size = int(request.args.get('page_size', 20))
        page = int(request.args.get('page', 1))
        if parent_id:
            parent_id = int(parent_id)
        params = {
            'parentId': parent_id,
            'page': page,
            'pageSize': page_size
        }
        rep = requests.get(
            'http://{host}:{post}/ioc-api/system_index/getIndexList'.format(host=config.system_monitoring.HOST,
                                                                            post=config.system_monitoring.POST
                                                                            ),
            params=params, headers={'clientId': "99"}).json()

        return jsonify(code=StatesCode.SUCCESS, message='成功', data=rep)


edit_index = reqparse.RequestParser(bundle_errors=True)
edit_index.add_argument(name='data', type=str, location='form', required=False)
# edit_index.add_argument(name='compare', type=str, location='form', required=False)
# edit_index.add_argument(name='defaultValue', type=str, location='form', required=False)
# edit_index.add_argument(name='isDel', type=str, location='form', required=False)
# edit_index.add_argument(name='name', type=str, location='form', required=False)
# edit_index.add_argument(name='parentId', type=str, location='form', required=False)
# edit_index.add_argument(name='remark', type=str, location='form', required=False)
# edit_index.add_argument(name='rule', type=str, location='form', required=False)
# edit_index.add_argument(name='units', type=str, location='form', required=False)
# edit_index.add_argument(name='useSite', type=str, location='form', required=False)


@ns.route('/edit_index')
class EditIndex(Resource):

    @ns.doc(description='编辑指标')
    @ns.expect(edit_index)
    def post(self):
        """编辑指标"""
        # id = request.form.get('id')
        # compare = request.form.get('compare')
        # defaultValue = request.form.get('defaultValue')
        # isDel = request.form.get('isDel')
        # name = request.form.get('name')
        # parentId = request.form.get('parentId')
        # remark = request.form.get('remark')
        # rule = request.form.get('rule')
        # units = request.form.get('units')
        # useSite = request.form.get('useSite')
        data =request.form.get('data')
        print(json.loads(data))

        # data = {
        #     "compare": compare,
        #     "defaultValue": defaultValue,
        #     "id": id,
        #     "isDel": isDel,
        #     "name": name,
        #     "parentId": parentId,
        #     "remark": remark,
        #     "rule": rule,
        #     "units": units,
        #     "useSite": useSite
        # }
        rep = requests.post(
            'http://{host}:{post}/ioc-api/system_index/editIndex'.format(host=config.system_monitoring.HOST,
                                                                                  post=config.system_monitoring.POST
                                                                                  ),
            json=json.loads(data), headers={'clientId': "99", "content-type": "application/json"}).json()

        return jsonify(code=StatesCode.SUCCESS, message='成功', data=rep)



get_system_menus_list = reqparse.RequestParser(bundle_errors=True)
get_system_menus_list.add_argument(name='parentId', type=int, location='args', required=False)


@ns.route('/get_system_menus_list')
class SystemMenusListApi(Resource):

    @ns.doc(description='查询所有菜单')
    @ns.expect(get_system_menus_list)
    def get(self):
        """查询所有菜单"""
        parentId = request.args.get('parentId')

        if parentId:
            parentId = int(parentId)

        params = {
            'parentId': parentId,

        }

        rep = requests.get(
            'http://{host}:{post}/ioc-api/system_index/getSystemMenusList'.format(host=config.system_monitoring.HOST,
                                                                                  post=config.system_monitoring.POST
                                                                                  ),
            params=params, headers={'clientId': "99"}).json()

        return jsonify(code=StatesCode.SUCCESS, message='成功', data=rep)
